@@ -1,6 +1,6 @@
 echo "<module>";
-echo "<name>top</name>";
-echo "<type>generic_data_string</type>";
+echo "<name><![CDATA[top]]></name>";
+echo "<type><![CDATA[generic_data_string]]></type>";
 echo "<data><![CDATA["
 top -b -n 1
 echo "]]></data>"
